==> chromium_102.0.5005.61.orig.tar.xz: chromium-102.0.5005.61/ash/services/device_sync/public/cpp/device_sync_prefs.cc <==
// Copyright 2020 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ash/services/device_sync/public/cpp/device_sync_prefs.h"

#include "ash/constants/ash_features.h"
#include "ash/services/device_sync/cryptauth_device_manager.h"
#include "ash/services/device_sync/cryptauth_device_registry_impl.h"
#include "ash/services/device_sync/cryptauth_enrollment_manager_impl.h"
#include "ash/services/device_sync/cryptauth_gcm_manager.h"
#include "ash/services/device_sync/cryptauth_key_registry_impl.h"
#include "ash/services/device_sync/cryptauth_metadata_syncer_impl.h"
#include "ash/services/device_sync/cryptauth_scheduler_impl.h"
#include "ash/services/device_sync/cryptauth_v2_enrollment_manager_impl.h"
#include "ash/services/device_sync/synced_bluetooth_address_tracker_impl.h"
#include "base/feature_list.h"
#include "components/prefs/pref_registry_simple.h"

namespace ash {
namespace device_sync {

void RegisterProfilePrefs(PrefRegistrySimple* registry) {
  CryptAuthGCMManager::RegisterPrefs(registry);
  CryptAuthDeviceManager::RegisterPrefs(registry);
  if (base::FeatureList::IsEnabled(
          chromeos::features::kCryptAuthV2Enrollment)) {
    CryptAuthV2EnrollmentManagerImpl::RegisterPrefs(registry);
    CryptAuthKeyRegistryImpl::RegisterPrefs(registry);
    CryptAuthSchedulerImpl::RegisterPrefs(registry);
  } else {
    CryptAuthEnrollmentManagerImpl::RegisterPrefs(registry);
  }

  if (features::ShouldUseV2DeviceSync()) {
    CryptAuthDeviceRegistryImpl::RegisterPrefs(registry);
    CryptAuthMetadataSyncerImpl::RegisterPrefs(registry);
    SyncedBluetoothAddressTrackerImpl::RegisterPrefs(registry);
  }
}

}  // namespace device_sync
}  // namespace ash

==> chromium_108.0.5359.124.orig.tar.xz: chromium-108.0.5359.124/ash/services/device_sync/public/cpp/device_sync_prefs.cc <==
// Copyright 2020 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "ash/services/device_sync/public/cpp/device_sync_prefs.h"

#include "ash/constants/ash_features.h"
#include "ash/services/device_sync/attestation_certificates_syncer_impl.h"
#include "ash/services/device_sync/cryptauth_device_manager.h"
#include "ash/services/device_sync/cryptauth_device_registry_impl.h"
#include "ash/services/device_sync/cryptauth_enrollment_manager_impl.h"
#include "ash/services/device_sync/cryptauth_gcm_manager.h"
#include "ash/services/device_sync/cryptauth_key_registry_impl.h"
#include "ash/services/device_sync/cryptauth_metadata_syncer_impl.h"
#include "ash/services/device_sync/cryptauth_scheduler_impl.h"
#include "ash/services/device_sync/cryptauth_v2_enrollment_manager_impl.h"
#include "ash/services/device_sync/synced_bluetooth_address_tracker_impl.h"
#include "base/feature_list.h"
#include "components/prefs/pref_registry_simple.h"

namespace ash {
namespace device_sync {

void RegisterProfilePrefs(PrefRegistrySimple* registry) {
  CryptAuthGCMManager::RegisterPrefs(registry);
  CryptAuthDeviceManager::RegisterPrefs(registry);
  if (base::FeatureList::IsEnabled(
          chromeos::features::kCryptAuthV2Enrollment)) {
    CryptAuthV2EnrollmentManagerImpl::RegisterPrefs(registry);
    CryptAuthKeyRegistryImpl::RegisterPrefs(registry);
    CryptAuthSchedulerImpl::RegisterPrefs(registry);
  } else {
    CryptAuthEnrollmentManagerImpl::RegisterPrefs(registry);
  }

  if (features::ShouldUseV2DeviceSync()) {
    CryptAuthDeviceRegistryImpl::RegisterPrefs(registry);
    CryptAuthMetadataSyncerImpl::RegisterPrefs(registry);
    SyncedBluetoothAddressTrackerImpl::RegisterPrefs(registry);
  }

  if (base::FeatureList::IsEnabled(chromeos::features::kEcheSWA)) {
    AttestationCertificatesSyncerImpl::RegisterPrefs(registry);
  }
}

}  // namespace device_sync
}  // namespace ash
